@@ -16,8 +16,8 @@ import yaml  # For saving config if save_config helper doesn't exist
 
 # TODO: Consider moving subprocess_manager functions to a more central location if used by core CLI
 try:
-    from development.utils.subprocess_manager import start_ngrok_and_get_url  # Added ngrok function
     from development.utils.subprocess_manager import (
+        start_ngrok_and_get_url,  # Added ngrok function
         start_process,
         start_serveo_and_get_url,
         stop_process,
@@ -59,9 +59,12 @@ except ImportError:
 
 
 from eval_protocol.auth import get_fireworks_account_id
-from eval_protocol.config import GCPCloudRunConfig, RewardKitConfig
-from eval_protocol.config import _config_file_path as global_loaded_config_path
-from eval_protocol.config import get_config
+from eval_protocol.config import (
+    GCPCloudRunConfig,
+    RewardKitConfig,
+    _config_file_path as global_loaded_config_path,
+    get_config,
+)
 from eval_protocol.evaluation import create_evaluation
 from eval_protocol.gcp_tools import (
     build_and_push_docker_image,
@@ -93,7 +96,7 @@ def _establish_local_server_and_tunnel(args):
     function_ref = args.function_ref
     local_server_port = args.local_port
 
-    log_dir = os.path.join(os.getcwd(), "logs", "reward-kit-local")
+    log_dir = os.path.join(os.getcwd(), "logs", "eval-protocol-local")
     os.makedirs(log_dir, exist_ok=True)
     generic_server_log_path = os.path.join(log_dir, f"generic_server_{evaluator_id}.log")
 
@@ -270,9 +273,9 @@ def _deploy_to_gcp_cloud_run(args, current_config, gcp_config_from_yaml):
 
         gcp_sanitized_eval_id = "".join(filter(lambda char: char.isalnum() or char in ["-", "_"], args.id))
         if not gcp_sanitized_eval_id:
-            gcp_sanitized_eval_id = "rewardkit-evaluator"
+            gcp_sanitized_eval_id = "evalprotocol-evaluator"
         secret_id_for_auth_key = f"rk-eval-{gcp_sanitized_eval_id}-authkey"
-        secret_labels = {"managed-by": "reward-kit", "evaluator-id": evaluator_id}
+        secret_labels = {"managed-by": "eval-protocol", "evaluator-id": evaluator_id}
 
         api_key_secret_version_id = ensure_gcp_secret(
             project_id=gcp_project_id,
